@@ -5,13 +5,13 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.07'; # 2003-04-06 (since 1999)
+our $VERSION = '0.08'; # 2003-04-18 (since 1999)
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(datetime_rfc2822);
 
-sub datetime_rfc2822 {
+sub datetime_rfc2822 ($;$) {
 	my($universal_time, $timezone) = @_;
 	
 	unless ($timezone) {
@@ -67,7 +67,7 @@ Because it has an alphabetical string C<GMT> for indicating a timezone. Now the
 
  Thu, 06 Mar 2003 19:14:05 -0000
 
-Moreover, the RFC2822 describes timezone SHOULD express local-time. The timezone C<-0000> does not mean the local-time of GMT (Greenwich Mean Time) but does universal-time (UTC). If it mean local-time at a place of GMT, the timezone C<+0000> SHOULD be used. So you know where you are and the local timezone's offset from UTC, you would specify timezone and local-time. For example, when you were at the time of second example of UTC, and you were in Japanese local-time where it is ahead of nine hours from UTC, the date-time expression is:
+Moreover, the RFC2822 describes timezone SHOULD express local-time. The timezone C<-0000> does not mean the local-time of GMT (Greenwich Mean Time) but does universal-time (UTC). If it mean local-time at an area of GMT, the timezone C<+0000> SHOULD be used. So you know your area's local timezone's offset from UTC that you should specify timezone and local-time. For example, at the time of above (2nd) example in UTC, and you were at an area of Japanese local-time, where it is ahead of nine hours from UTC, the date-time expression is:
 
  Fri, 07 Mar 2003 04:14:05 +0900
 
@@ -79,9 +79,9 @@ Please consult RFC2822 (section 3.3, 4.3) for the actual infomation.
 
 =over
 
-=item datetime_rfc2822($machine_time [, $timezone])
+=item datetime_rfc2822($unix_time [, $timezone])
 
-This function returns RFC2822 compliant date-time string which is converted from a unix-machine-time. Though $timezone value is optional, it is said that in the RFC2822 I<The date and time-of-day SHOULD express local time>. If $timezone value is not given (omitted), it will be not taken as a local-time but as a universal-time (UTC) to be expressed C<-0000>.
+This function returns RFC2822 compliant date-time string which is converted from a C<$unix_time> which is offset in seconds from the unix epoch time (1970-01-01 00:00:00 UTC). Though $timezone value is optional, it is said that in the RFC2822 I<The date and time-of-day SHOULD express local time>. If $timezone value is not given (omitted), it will be not taken as a local-time but as a universal-time (UTC) to be expressed C<-0000>.
 
 The time zone expression should be compliant to the RFC2822 specification. It must be within the range -9959 through +9959. The "+" or "-" indicates whether the time-of-day is ahead of (i.e., east of) or behind (i.e., west of) Universal Time. The first two digits indicate the number of hours difference from Universal Time, and the last two digits indicate the number of minutes difference from Universal Time. (Hence, +hhmm means +(hh * 60 + mm) minutes, and -hhmm means -(hh * 60 + mm) minutes). The form "+0000" should be used to indicate a time zone at Universal Time.
 
